@@ -8,8 +8,6 @@ type DestroyOptions struct {
 	Concurrency int
 	// SkipDeps is the skip deps flag
 	SkipDeps bool
-	// Interactive is true if the user should be prompted for input.
-	Interactive bool
 }
 
 // NewDestroyOptions creates a new Apply
@@ -45,8 +43,3 @@ func (c *DestroyImpl) Args() string {
 func (c *DestroyImpl) SkipDeps() bool {
 	return c.DestroyOptions.SkipDeps
 }
-
-// Interactive returns the Interactive
-func (c *DestroyImpl) Interactive() bool {
-	return c.DestroyOptions.Interactive
-}
