@@ -44,6 +44,10 @@ type GlobalOptions struct {
 	AllowNoMatchingRelease bool
 	// logger is the logger to use.
 	logger *zap.SugaredLogger
+	// EnableLiveOutput enables live output from the Helm binary stdout/stderr into Helmfile own stdout/stderr
+	EnableLiveOutput bool
+	// Interactive is true if the user should be prompted for input.
+	Interactive bool
 }
 
 // Logger returns the logger to use.
@@ -120,6 +124,11 @@ func (g *GlobalImpl) StateValuesFiles() []string {
 	return g.GlobalOptions.StateValuesFile
 }
 
+// EnableLiveOutput return when to pipe the stdout and stderr from Helm live to the helmfile stdout
+func (g *GlobalImpl) EnableLiveOutput() bool {
+	return g.GlobalOptions.EnableLiveOutput
+}
+
 // Logger returns the logger
 func (g *GlobalImpl) Logger() *zap.SugaredLogger {
 	return g.GlobalOptions.logger
@@ -172,3 +181,8 @@ func (g *GlobalImpl) ValidateConfig() error {
 	}
 	return nil
 }
+
+// Interactive returns the Interactive
+func (g *GlobalImpl) Interactive() bool {
+	return g.GlobalOptions.Interactive
+}
