@@ -14,6 +14,8 @@ import (
 	"github.com/Masterminds/semver/v3"
 	"go.uber.org/zap"
 	"go.uber.org/zap/zapcore"
+	"gopkg.in/yaml.v3"
+	"helm.sh/helm/v3/pkg/chart"
 	"helm.sh/helm/v3/pkg/cli"
 	"helm.sh/helm/v3/pkg/plugin"
 
@@ -239,7 +241,7 @@ func (helm *execer) SyncRelease(context HelmContext, name, chart string, flags .
 		env["HELM_TILLER_HISTORY_MAX"] = strconv.Itoa(context.HistoryMax)
 	}
 
-	out, err := helm.exec(append(append(preArgs, "upgrade", "--install", "--reset-values", name, chart), flags...), env, nil)
+	out, err := helm.exec(append(append(preArgs, "upgrade", "--install", name, chart), flags...), env, nil)
 	helm.write(nil, out)
 	return err
 }
@@ -420,7 +422,7 @@ func (helm *execer) DiffRelease(context HelmContext, name, chart string, suppres
 		enableLiveOutput := false
 		overrideEnableLiveOutput = &enableLiveOutput
 	}
-	out, err := helm.exec(append(append(preArgs, "diff", "upgrade", "--reset-values", "--allow-unreleased", name, chart), flags...), env, overrideEnableLiveOutput)
+	out, err := helm.exec(append(append(preArgs, "diff", "upgrade", "--allow-unreleased", name, chart), flags...), env, overrideEnableLiveOutput)
 	// Do our best to write STDOUT only when diff existed
 	// Unfortunately, this works only when you run helmfile with `--detailed-exitcode`
 	detailedExitcodeEnabled := false
@@ -599,3 +601,21 @@ func resolveOciChart(ociChart string) (ociChartURL, ociChartTag string) {
 	ociChartURL = fmt.Sprintf("oci://%s", ociChart[:urlTagIndex])
 	return ociChartURL, ociChartTag
 }
+
+func (helm *execer) ShowChart(chartPath string) (chart.Metadata, error) {
+	if !helm.IsHelm3() {
+		// show chart command isn't supported in helm2
+		return chart.Metadata{}, fmt.Errorf("helm show isn't supported in helm2")
+	}
+	var helmArgs = []string{"show", "chart", chartPath}
+	out, error := helm.exec(helmArgs, map[string]string{}, nil)
+	if error != nil {
+		return chart.Metadata{}, error
+	}
+	var metadata chart.Metadata
+	error = yaml.Unmarshal(out, &metadata)
+	if error != nil {
+		return chart.Metadata{}, error
+	}
+	return metadata, nil
+}
