@@ -28,7 +28,7 @@ func get(path string, varArgs ...interface{}) (interface{}, error) {
 		def = varArgs[0]
 		obj = varArgs[1]
 	default:
-		return nil, fmt.Errorf("unexpected number of args pased to the template function get(path, [def, ]obj): expected 1 or 2, got %d, args was %v", len(varArgs), varArgs)
+		return nil, fmt.Errorf("unexpected number of args passed to the template function get(path, [def, ]obj): expected 1 or 2, got %d, args was %v", len(varArgs), varArgs)
 	}
 
 	if path == "" {
